var CookieConsent = Class.create({
  initialize : function(settings) {
    this.settings = settings;
    //this.clearCookie('cookieConsent'); // for debugging
    if(!this.getCookie('cookieConsent')){
      this.showDisclaimer();
    }
    var resetCookiesButton = $('ResetCookies');
    if (resetCookiesButton != null) {
      resetCookiesButton.observe('click', function() {
        this.showDisclaimer();
      }.bind(this));
    }
  },

  getCookie : function(key)
  {
    var keyEquals = key + "=";
    var value     = false;

    document.cookie.split(';').invoke('strip').each(function(s){
      if (s.startsWith(keyEquals)) {
        value = unescape(s.substring(keyEquals.length, s.length));
      }
    });

    return value;
  },

  setCookie : function(key, value, days) {
    var setValue      = key + '=' + escape(new String(value));
    var setExpiration = "";

    if (days) {
      var date = new Date();
      date.setTime(date.getTime() + (days*24*60*60*1000));
      var setExpiration = "; expires=" + date.toGMTString();
    }

    var cookieString = setValue + setExpiration + ";path=/";
    document.cookie  = cookieString;
  },

  clearCookie : function(key) {
    this.setCookie(key,'',-1);
  },

  animation : function(event, element) {
    switch(this.settings.animation)
    {
      case 'none': 
        event == 'show' ? $(element).show() : $(element).hide(); break;
      case 'slide': 
        event == 'show' ? Effect.BlindDown(element, { duration : 1 }) : Effect.BlindUp(element, { duration : 1 }); break;
      case 'fade':
        event == 'show' ? Effect.Appear(element, { duration : 1 }) : Effect.Fade(element, { duration : 1 }); break;
    }
  },

  showDisclaimer : function() {
    clearLessCache();
    if (this.settings.activeCookieTypes === '') {
      return;
    }
    var activeCookieTypes = this.settings.activeCookieTypes.split(',');

    var htmlContent1 = this.settings.disclaimer1
                     + '<button class="button" role="button" name="cookieConsentHide" id="cookieConsentHide">'
                     + this.settings.buttonText
                     + '</button>'
                     + '<button class="button" role="button" name="cookieConsentConfig" id="cookieConsentConfig">'
                     + this.settings.configButtonText
                     + '</button>';

    var htmlContent2 = this.settings.disclaimer2 + '<div id="CookieSelectPane">';

    for (i = 0; i < activeCookieTypes.length; i++) {
      var element = activeCookieTypes[i];
      var label = this.settings[element + 'Label'];
      var infoBox = this.settings[element + 'InfoBox'];
      var disabled = '';
      if (element === 'necessary') {
        label = this.settings.mandatoryLabel;
        disabled = 'disabled="disabled" checked="checked"';
      }
      htmlContent2 = htmlContent2
                   + '<div class="CookieSelectButtonWrapper" title="' + infoBox + '">'
                   + '<label for="CookieButton' + label + '">'
                   + '<input id="CookieButton' + label + '" class="CookieButton" tabindex="1" ' + disabled +' type="checkbox">'
                   + label + '</label>'
                   + '</div>';
    }

    htmlContent2 = htmlContent2 + '</div><button class="button" role="button" name="cookieConsentOK" id="cookieConsentOK">OK</button>';

    var html = '<div id="cookieConsent" style="display: none;">'
             + '<div class="col-md-2"></div>'
             + '<div id="cookieConsentContent" class="col-md-8">'
             + htmlContent1
             + '</div>'
             + '<div class="col-md-2"></div>'
             + '</div>'
             + '</div>';

    $('xwikimaincontainerinner').insert( {before : html } );
    $("cookieConsentHide").observe('click', this.hideDisclaimer.bind(this, activeCookieTypes));
    $("cookieConsentConfig").addEventListener("click", function(){
      $("cookieConsentContent").innerHTML = htmlContent2;
      $("cookieConsentOK").observe('click', function() {
        for (i = 0; i < activeCookieTypes.length; i++) {
          var element = activeCookieTypes[i];
          var label = this.settings[element + 'Label'];
          if (element === 'necessary') {
            label = this.settings.mandatoryLabel;
          }
          if(!$('CookieButton' + label).checked) {
            var index = activeCookieTypes.indexOf(element);
            if (index > -1) {
              activeCookieTypes.splice(index, 1);
            }
          }
        }
        this.hideDisclaimer(activeCookieTypes);
      }.bind(this));
    }.bind(this));

    this.animation('show', 'cookieConsent');
  },

  hideDisclaimer : function(param) {
    this.setCookie('cookieConsent', 'hide', 365);
    this.setCookie('gdprSettings', param, 365);
    this.animation('hide', 'cookieConsent');
  }
});

